create_log_file

Function create_log_file 

pub fn create_log_file(base_path: &Path) -> Result<(File, PathBuf)>
Creates a new timestamped log file in .ralph/diagnostics/logs/.

Creates the directory if needed, rotates old logs, and returns the file handle and path of the newly created log file.