HookExecutorError

Enum HookExecutorError 

pub enum HookExecutorError {
    EmptyCommand {
        phase_event: String,
        hook_name: String,
    },
    CommandResolution {
        phase_event: String,
        hook_name: String,
        command: String,
        reason: String,
    },
    Spawn {
        phase_event: String,
        hook_name: String,
        command: String,
        cwd: String,
        source: Error,
    },
    StdinSerialize {
        phase_event: String,
        hook_name: String,
        command: String,
        source: Error,
    },
    StdinWrite {
        phase_event: String,
        hook_name: String,
        command: String,
        source: Error,
    },
    TimeoutTerminate {
        phase_event: String,
        hook_name: String,
        command: String,
        timeout_seconds: u64,
        source: Error,
    },
    OutputRead {
        phase_event: String,
        hook_name: String,
        command: String,
        stream: &'static str,
        source: Error,
    },
    OutputCollectorJoin {
        phase_event: String,
        hook_name: String,
        command: String,
        stream: &'static str,
    },
    Wait {
        phase_event: String,
        hook_name: String,
        command: String,
        source: Error,
    },
}
Hook executor errors.

Variants



EmptyCommand

Command argv is missing an executable entry.

Fields

phase_event: String
hook_name: String


CommandResolution

Command argv executable could not be resolved to a launchable binary path.

Fields

phase_event: String
hook_name: String
command: String
reason: String


Spawn

Process spawn failed after command/cwd/env resolution.

Fields

phase_event: String
hook_name: String
command: String
source: Error


StdinSerialize

Serializing the JSON stdin payload failed.

Fields

phase_event: String
hook_name: String
command: String
source: Error


StdinWrite

Writing stdin payload bytes to the child process failed.

Fields

phase_event: String
hook_name: String
command: String
source: Error


TimeoutTerminate

Timeout enforcement attempted to terminate the process but kill failed.

Fields

phase_event: String
hook_name: String
command: String
timeout_seconds: u64
source: Error


OutputRead

Reading captured stdout/stderr bytes failed.

Fields

phase_event: String
hook_name: String
command: String
stream: &'static str
source: Error


OutputCollectorJoin

Output collector thread panicked while reading stdout/stderr.

Fields

phase_event: String
hook_name: String
command: String
stream: &'static str


Wait

Waiting for spawned process completion failed.

Fields

phase_event: String
hook_name: String
command: String
source: Error