pub fn create_log_file(base_path: &Path) -> Result<(File, PathBuf)>Expand description
Creates a new timestamped log file in .ralph/diagnostics/logs/.
Creates the directory if needed, rotates old logs, and returns the file handle and path of the newly created log file.