pub enum HookExecutorError {
EmptyCommand {
phase_event: String,
hook_name: String,
},
CommandResolution {
phase_event: String,
hook_name: String,
command: String,
reason: String,
},
Spawn {
phase_event: String,
hook_name: String,
command: String,
cwd: String,
source: Error,
},
StdinSerialize {
phase_event: String,
hook_name: String,
command: String,
source: Error,
},
StdinWrite {
phase_event: String,
hook_name: String,
command: String,
source: Error,
},
TimeoutTerminate {
phase_event: String,
hook_name: String,
command: String,
timeout_seconds: u64,
source: Error,
},
OutputRead {
phase_event: String,
hook_name: String,
command: String,
stream: &'static str,
source: Error,
},
OutputCollectorJoin {
phase_event: String,
hook_name: String,
command: String,
stream: &'static str,
},
Wait {
phase_event: String,
hook_name: String,
command: String,
source: Error,
},
}Expand description
Hook executor errors.
Variants
EmptyCommand
Command argv is missing an executable entry.
CommandResolution
Command argv executable could not be resolved to a launchable binary path.
Spawn
Process spawn failed after command/cwd/env resolution.
StdinSerialize
Serializing the JSON stdin payload failed.
StdinWrite
Writing stdin payload bytes to the child process failed.
TimeoutTerminate
Timeout enforcement attempted to terminate the process but kill failed.
OutputRead
Reading captured stdout/stderr bytes failed.
OutputCollectorJoin
Output collector thread panicked while reading stdout/stderr.
Wait
Waiting for spawned process completion failed.