pub struct LoopEntry {
pub id: String,
pub pid: u32,
pub started: DateTime<Utc>,
pub prompt: String,
pub worktree_path: Option<String>,
pub workspace: String,
}Expand description
Metadata for a registered loop.
Fields
id: StringUnique loop ID: loop-{unix_timestamp}-{4_hex_chars}
pid: u32Process ID of the loop.
started: DateTime<Utc>When the loop was started.
prompt: StringThe prompt/task being executed.
worktree_path: Option<String>Path to the worktree (None if running in main workspace).
workspace: StringThe workspace root where the loop is running.
Implementations
Sourceimpl LoopEntry
impl LoopEntry
Sourcepub fn new(
prompt: impl Into<String>,
worktree_path: Option<impl Into<String>>,
) -> Self
pub fn new( prompt: impl Into<String>, worktree_path: Option<impl Into<String>>, ) -> Self
Creates a new loop entry for the current process.
Sourcepub fn with_workspace(
prompt: impl Into<String>,
worktree_path: Option<impl Into<String>>,
workspace: impl Into<String>,
) -> Self
pub fn with_workspace( prompt: impl Into<String>, worktree_path: Option<impl Into<String>>, workspace: impl Into<String>, ) -> Self
Creates a new loop entry with a specific workspace.