pub struct HatConfig {
pub name: String,
pub description: Option<String>,
pub triggers: Vec<String>,
pub publishes: Vec<String>,
pub instructions: String,
pub backend: Option<HatBackend>,
pub default_publishes: Option<String>,
}Expand description
Configuration for a single hat.
Fields
name: StringHuman-readable name for the hat.
description: Option<String>Short description of the hat’s purpose (required). Used in the HATS table to help Ralph understand when to delegate to this hat.
triggers: Vec<String>Events that trigger this hat to be worn. Per spec: “Hats define triggers — which events cause Ralph to wear this hat.”
publishes: Vec<String>Topics this hat publishes.
instructions: StringInstructions prepended to prompts.
backend: Option<HatBackend>Backend to use for this hat (inherits from cli.backend if not specified).
default_publishes: Option<String>Default event to publish if hat forgets to write an event.
Implementations