pub struct HatInfo {
pub name: String,
pub description: String,
pub subscribes_to: Vec<String>,
pub publishes: Vec<String>,
pub instructions: String,
pub event_receivers: HashMap<String, Vec<EventReceiver>>,
pub disallowed_tools: Vec<String>,
}Expand description
Information about a hat for prompt generation.
Fields
name: Stringdescription: Stringsubscribes_to: Vec<String>publishes: Vec<String>instructions: Stringevent_receivers: HashMap<String, Vec<EventReceiver>>Maps each published event to the hats that receive it.
disallowed_tools: Vec<String>Tools the hat is not allowed to use (prompt-level enforcement).
Implementations